function [self] = read_xls_file(self)
% read Microsoft Excel Spreadsheet file and parse it
%
% $Id$

% check file validity
% -------------------
[type, sheet] = xlsfinfo( self.file);

if ~strcmp(type, 'Microsoft Excel Spreadsheet')
  error('dynaload:dynaload', ...
    ['The specified data file ''%s'' does not exist\n' ...
    'or is not a valid Microsoft Excel Spreadsheet'],...
    self.file);
end

if isempty( sheet)
  error('dynaload:dynaload', ...
    'The specified data file ''%s'' does not contain valid sheet',...
    self.file);
end

% loop over each excel sheet
% --------------------------
for k=1:length(sheet)

  % associate each sheet name to key
  % --------------------------------
  key = sheet{k};

  % create a temporary hashtable use to store data read in each sheet
  % -----------------------------------------------------------------
  hash = hashtable;

  % read Excel worksheet in raw mode (unprocessed cell content) which
  % contains both numeric and text data, empty cell is fillwith NaN
  % -----------------------------------------------------------------
  [A,B,raw] = xlsread( self.file, sheet{k} );

  % get size of each sheet
  % ----------------------
  [line,column] = size(raw);

  % jump the 2 header lines
  % -----------------------
  for i=3:line
    
    % loop over other members find in first line
    % ------------------------------------------
    for j=1:column

      % get member, type and value dynamicaly
      % -------------------------------------
      member = genvarname(raw{1,j});
      type   = genvarname(raw{2,j});
      value  = raw{i,j};

      % get key name 
      % ------------
      if ischar(value) && ~isempty(regexp(member, 'key__$','ONCE'))
        key__ = value;
        %continue;
      end
        
      % dynamically populate structure 'theStruct'
      % ------------------------------------------
      if isnan(value)
        
        % when value is empty, give the rigth type to empty value, expect
        % for logical, that is false by default
        % ---------------------------------------------------------------
        switch type
          case {'logical','boolean'}
            theStruct.(member) = false;
          case 'char'
            theStruct.(member) = char([]);
          case {'integer','int8','int16','int32','int','long'}
            theStruct.(member) = int32([]);
          case {'float','single'}
            theStruct.(member) = single([]);
          case {'double','real'}
            theStruct.(member) = double([]);
        end   
        
      else
        
        switch type
          
          case {'logical','boolean'}
            % logical value sould be 0,1 or char 'true' or 'false'
            % and must be converted to logical true or fase
            % -------------------------------------------
            if ischar(value) && ~isempty(regexp(value, '^(true|false)$','ONCE'))
               theStruct.(member) = logical(eval(value));
            elseif isnumeric(value) && (value == 0 || value == 1)   
              theStruct.(member) = logical(value);
            else  
              theStruct.(member) = false;
            end
            
          case 'char'
            % nothing to do, just assign value to struct
            % -------------------------------------------
            theStruct.(member) = value;
            
          case 'cell'
            % eval needed to construct matlab cell expression
            % -----------------------------------------------
            theStruct.(member) = eval(['{' value '}']);

          case {'integer','int8','int16','int32','int','long'}
            % Excel use dot in english format and comma in french
            % real number with dot is character in french
            % -------------------------------------------
            if ischar(value)
              theStruct.(member) = int32(str2double(value));
            else
              theStruct.(member) = int32(value);
            end
            
          case {'float','single'}
            % 
            % -------------------------------------------
            if ischar(value)
              theStruct.(member) = single(str2double(value));
            else
              theStruct.(member) = single(value);
            end

         case {'double','real'}
            % 
            % -------------------------------------------
            if ischar(value)
              theStruct.(member) = str2double(value);
            else
              theStruct.(member) = double(value);
            end
            
          otherwise
            theStruct.(member) = char(value);

        end
        
      end

    end % end for j

    % populate the hashtable with key and structure
    % ---------------------------------------------
    hash = put(hash, key__, theStruct);

    % initialize internal structure for next loop
    % -------------------------------------------
    theStruct = []; key__ = [];

  end % end for i

  % populate dynaload objet (self) with sheet name (key) and hash
  % ------------------------------------------------------------
  self = put(self, key, hash);
  
end % end of sheet

end
